<!--
This file is automatically generated by tfds.scripts.documentation.build_community_catalog
and all modifications will be erased, please edit the
original build_community_catalog.py file.
-->
# Community Datasets

The datasets documented here are created by the community. The dataset builder
code lives in external repositories. Repositories with dataset builders can be
added in [here](https://github.com/tensorflow/datasets/blob/master/tensorflow_datasets/community-datasets.toml).

---

## Usage

See our [getting-started guide](https://www.tensorflow.org/datasets/overview)
for a quick introduction.

```python
for ex in tfds.load('namespace:dataset', split='train'):
  ...
```

## All Datasets

{toc}

---
